pub struct CRFrame {
pub index: HashMap<String, (u64, CRFrameObjectType)>,
pub bytestorage: Vec<u8>,
pub tof_paddles: Arc<HashMap<u8, TofPaddle>>,
pub trk_strips: Arc<HashMap<u32, TrackerStrip>>,
pub trk_masks: Arc<HashMap<u32, TrackerStripMask>>,
pub trk_ped: Arc<HashMap<u32, TrackerStripPedestal>>,
pub trk_tf: Arc<HashMap<u32, TrackerStripTransferFunction>>,
pub trk_cmn: Arc<HashMap<u32, TrackerStripCmnNoise>>,
pub do_trk_calib: bool,
pub subtract_trk_cmn: bool,
pub timestamp: Option<f64>,
}Expand description
The central data container of the caraspace suite.
A CRFrame can hold multiple CRFrameObjects and is basically a little sclerite of the entire skeleton.
Fields
index: HashMap<String, (u64, CRFrameObjectType)>bytestorage: Vec<u8>tof_paddles: Arc<HashMap<u8, TofPaddle>>trk_strips: Arc<HashMap<u32, TrackerStrip>>trk_masks: Arc<HashMap<u32, TrackerStripMask>>trk_ped: Arc<HashMap<u32, TrackerStripPedestal>>trk_tf: Arc<HashMap<u32, TrackerStripTransferFunction>>trk_cmn: Arc<HashMap<u32, TrackerStripCmnNoise>>do_trk_calib: boolTRK calibration - convert to energy
subtract_trk_cmn: boolTRK subtract CMN
timestamp: Option<f64>Implementations
Sourceimpl CRFrame
impl CRFrame
pub fn new() -> Self
Sourcepub fn get_tracker_hitseries(
&self,
source: TrackerHitSource,
name: Option<String>,
) -> Result<Vec<TrackerHit>, SerializationError>
pub fn get_tracker_hitseries( &self, source: TrackerHitSource, name: Option<String>, ) -> Result<Vec<TrackerHit>, SerializationError>
Extract trackerhits across the frame.
Sources for tracker hits can either be the regular TelemetryEvents, or all the different TrackerHits.
pub fn get_telemetrypacket_gcutime_range(&self) -> Option<(f64, f64, f64)>
pub fn serialize_index(&self) -> Vec<u8> ⓘ
pub fn string_to_bytes(value: String) -> Vec<u8> ⓘ
pub fn parse_index( stream: &Vec<u8>, pos: &mut usize, ) -> HashMap<String, (u64, CRFrameObjectType)>
Sourcepub fn put<T: Serialization + Frameable>(&mut self, object: T, name: &str)
pub fn put<T: Serialization + Frameable>(&mut self, object: T, name: &str)
Store any eligible object in the frame
Eligible object must implement the “Frameable” trait
Sourcepub fn has(&self, name: &str) -> bool
pub fn has(&self, name: &str) -> bool
Check if the frame contains an object with the given name
Arguments:
- name : The name of the object as it appears in the index
Sourcepub fn get_telemetry_event_names(&self) -> Vec<&str>
pub fn get_telemetry_event_names(&self) -> Vec<&str>
A list of TelemetryEvents (fka MergedEvent) in the frame
pub fn get_fobject( &self, name: &str, ) -> Result<CRFrameObject, SerializationError>
Sourcepub fn get_first_gcutime(&self) -> Option<f64>
pub fn get_first_gcutime(&self) -> Option<f64>
A check if the frame contains anything which is a telemetrypacket. This can be used to check if we can get the time of the telemetrypacket directly
pub fn get<T: Serialization + Frameable>( &self, name: &str, ) -> Result<T, SerializationError>
Sourcepub fn show_frame(&self) -> String
pub fn show_frame(&self) -> String
A verbose display of the frame content